@@ -1,5 +1,4 @@
 
-from foundry.xtract_method import *
 import time
 import h5py
 import glob
@@ -27,10 +26,10 @@ from foundry.models import (
     FoundrySpecification,
     FoundryDataset
 )
-from requests.packages.urllib3.exceptions import InsecureRequestWarning
 import logging
 import os
 import shutil
+from collections import deque
 logging.disable(logging.INFO)
 
 
@@ -46,6 +45,7 @@ class Foundry(FoundryMetadata):
     dlhub_client: Any
     forge_client: Any
     connect_client: Any
+    transfer_client: Any
     index = ""
 
     xtract_tokens: Any
@@ -110,6 +110,8 @@ class Foundry(FoundryMetadata):
             data_mdf_authorizer=auths["data_mdf"],
             petrel_authorizer=auths["petrel"],
         )
+        
+        self.transfer_client = auths['transfer']
 
         if index == "mdf":
             test = False
@@ -293,7 +295,7 @@ class Foundry(FoundryMetadata):
         """
         return self.dlhub_client.run(name, inputs=inputs, **kwargs)
 
-    def load_data(self, source_id=None, globus=True):
+    def load_data(self, source_id=None, as_hdf5=False):
         """Load in the data associated with the prescribed dataset
 
         Tabular Data Type: Data are arranged in a standard data frame
@@ -307,6 +309,8 @@ class Foundry(FoundryMetadata):
         Args:
            inputs (list): List of strings for input columns
            targets (list): List of strings for output columns
+           source_id (string): Relative path to the source file
+           as_hdf5 (bool): If True and dataset is in hdf5 format, keep data in hdf5 format
 
         Returns
         -------s
@@ -319,10 +323,10 @@ class Foundry(FoundryMetadata):
             if self.dataset.splits:
                 for split in self.dataset.splits:
                     data[split.label] = self._load_data(file=split.path,
-                                                        source_id=source_id, globus=globus)
+                                                        source_id=source_id, as_hdf5=as_hdf5)
                 return data
             else:
-                return {"data": self._load_data(source_id=source_id, globus=globus)}
+                return {"data": self._load_data(source_id=source_id, as_hdf5=as_hdf5)}
         except Exception as e:
             raise Exception(
                 "Metadata not loaded into Foundry object, make sure to call load()") from e
@@ -618,14 +622,19 @@ class Foundry(FoundryMetadata):
         else:
 
             source_id = self.mdf["source_id"]
-            xtract_config = {
-                 "xtract_base_url": "http://xtractcrawler5-env.eba-akbhvznm.us-east-1.elasticbeanstalk.com/",
-                 "source_ep_id": "82f1b5c6-6e9b-11e5-ba47-22000b92c6ec",
-                 "base_url": "https://data.materialsdatafacility.org",
-                 "folder_to_crawl": f"/foundry/{source_id}/",
-                 "grouper": "matio"
-                }
-            xtract_https_download(self, verbose=verbose, **xtract_config) # TODO: figure out better way than passing self?
+            https_config = {
+                "source_ep_id": "82f1b5c6-6e9b-11e5-ba47-22000b92c6ec",
+                "base_url": "https://data.materialsdatafacility.org",
+                "folder_to_crawl": f"/foundry/{self.mdf['source_id']}/",
+                "source_id":self.mdf["source_id"]
+            }
+            
+            task_list = list(recursive_ls(self.transfer_client, 
+                                          https_config['source_ep_id'], 
+                                          https_config['folder_to_crawl']))
+            # TODO Add parallel
+            for task in task_list:
+                download_file(task, https_config)
 
         # after download check making sure directory exists, contains all indicated files
         if os.path.isdir(path):
@@ -649,7 +658,7 @@ class Foundry(FoundryMetadata):
 
         return self
 
-    def build(self, spec, globus=False, interval=3, file=False):
+    def build(self, spec, globus=False, interval=3, file=False, as_object=False):
         """Build a Foundry Data Package
         Args:
             spec (multiple): dict or str (relative filename) of the data package specification
@@ -725,7 +734,7 @@ class Foundry(FoundryMetadata):
             return key_list
 
 
-    def _load_data(self, file=None, source_id=None, globus=True):
+    def _load_data(self, file=None, source_id=None, as_hdf5=False):
 
         # Build the path to access the cached data
         if source_id:
@@ -791,7 +800,9 @@ class Foundry(FoundryMetadata):
             tmp_data = {s: {} for s in special_types}
             for s in special_types:
                 for key in self.get_keys(s):
-                    if isinstance(f[key], h5py.Group):
+                    if as_hdf5:
+                        tmp_data[s][key] = f[key]
+                    elif isinstance(f[key], h5py.Group):
                         if is_pandas_pytable(f[key]):
                             df = pd.read_hdf(filepath, key)
                             tmp_data[s][key] = df
@@ -816,3 +827,53 @@ def is_doi(string: str):
         return True
     else:
         return False
+def _get_files(tc, ep, queue, max_depth):
+    while queue:
+        abs_path, rel_path, depth = queue.pop()
+        path_prefix = rel_path + "/" if rel_path else ""
+
+        res = tc.operation_ls(ep, path=abs_path)
+
+        if depth < max_depth:
+            queue.extend(
+                (
+                    res["path"] + item["name"],
+                    path_prefix + item["name"],
+                    depth + 1,
+                )
+                for item in res["DATA"]
+                if item["type"] == "dir"
+            )
+        for item in res["DATA"]:
+            if item["type"]=='file':
+                item["name"] = path_prefix + item["name"]
+                item["path"] = abs_path.replace('/~/','/')
+                yield item
+
+def recursive_ls(tc, ep, path, max_depth=3):
+    queue = deque()
+    queue.append((path, "", 0))
+    yield from _get_files(tc, ep, queue, max_depth)
+
+def download_file(item, https_config):
+        url = f"{https_config['base_url']}{item['path']}{item['name']}"
+        
+        # removes data source (eg MDF) parent directories, leaving the split path only
+        datasplit_subpath = item["path"].replace("/foundry/","/")
+
+        # build destination path for data file
+        destination = os.path.join("data/", https_config['source_id'], item['name'])
+
+        parent_path = os.path.split(destination)[0]
+
+        # if parent directories don't exist, create them
+        if not os.path.exists(parent_path):
+            os.makedirs(parent_path)
+
+        response = requests.get(url)
+
+        # write file to local destination
+        with open(destination, "wb") as f:
+            f.write(response.content)
+
+        return {destination + " status": True}
\ No newline at end of file
